@@ -29,9 +29,9 @@
   )
 
 */
-#include "err.h"
-#include "asn1_mac.h"
-#include "ssl.h"
+#include "openssl/err.h"
+#include "openssl/asn1_mac.h"
+#include "openssl/ssl.h"
 
 /*
  * "id"     a character string that is an identity within a zone
